==> Epics.uv8.13.tar.gz: epics/ZepTrackp.h <==
          real*8  Bxu,  Byu,  Bzu  ! uniform mag field comp.
          real*8  Exu,  Eyu,  Ezu  ! uniform elec field comp.
          integer MagField      ! how to give magnetic field
          integer ElecField     ! //          electric field
          real*8  DtMax         ! max allowable path in r.l
          real*8  Tcoef         !
          real*8  Tmin          !
          logical EdepdEdx      ! use energy dependent dE/dx
                                !  F is used to compare analytic calc.
          logical TimeStruc     !  
          logical Moliere       ! Moliere's scattering  or  Gaussian
          real*8  EminElec      ! e-'s E < EminElec is discarded
          real*8  EminGamma     ! Egamma < EminGamma is  discarded
          real*8 ElowerBndPair  ! Pair creation is neglected for Eg< this E
          real*8 EupperBndCS    ! Compton scattering is neglected Eg> this E
          integer IncGp         ! Include gp interactions or not
          logical Trace         ! how to take trace info.
          logical FreeC         ! first collision point is fixed or free
          real*8  EpsLeng       ! small distance to adjust boundary 
          real*8 RecoilKEmin    ! Knock-on electron's E> this E is treated
                                ! directly and not included dE/dx.
   	  real*8 Eanihi         ! Ee+ < Eanihi ==> anihilation is considered
          real*8 Ecut           ! cut off energy of brems. (obsolute)
          real*8 Escat          ! Modified scattering const. 
          integer Eabsorb       ! !0 --> photo electric absoption energy is
                                ! counted as energy loss in the media
          logical Photo         ! Photo-electric effect is considered or not
          logical Knckon        ! obsolute
          logical AngleB        ! T==>angle at bremsstrahlung is considered.
          integer ALateCor      ! Angular-Lateral correlated scattering
                                ! is used or not.   0-> no cor. 1 & Moliere=f
                                ! ==> Gaussian cor.  2 ==> even if Moliere=f,
                                !   Gaussian cor. is used.
          integer Sync          ! 0: No Synchrotron considered.
                                ! 1: energy loss by sync. for elec and 'sp'
                                !    if Magfield !=0.
                                ! 2; photon eimission is directly managed
                                !    note Eg is very low.
          integer MuNI          ! 0: no muon n.i, 1: all loss --> dE/dx
                                ! 2: dE/dx(v<vmin) -->  dE/dx. v>vmin is
                                ! by stacastic process. 3: same as 2 but
                                ! n.i is treated explicitly.
          integer MuBr          ! same as MuNI but for bremsstrahlung.
          integer MuPr          ! same as MuNI but for pair creation
          real*8  SyncLoop      ! electron may make a infinite loop in  'sp'.
                                ! If it runs SyncLoop * r, we discard it,
                                ! where r is the cycrtron radius.
          real*8  KEmin         ! minimum kinetic energy of heavy particls
                                ! such as mu, pi, n, p...
                                ! if 0, appropriate value is set by ref. to
                                ! EminElec
          integer MagPair       ! Magnetic pair production is considered or not
                                ! If 0, neglected. if 1 considered. 
                                ! It becomes effective, only if
                                ! Xai=B/Bc*Eg/me/2 > 0.05.
        common /epTrackC/  Bxu,  Byu,  Bzu, Exu, Eyu, Ezu,
     *  DtMax, Tcoef, Tmin, KEmin,
     *  EminElec,  EminGamma, EupperBndCS, IncGp,
     *  Trace,  FreeC, EpsLeng, SyncLoop,
     *  ElowerBndPair, RecoilKEmin,
     *  Eanihi, Ecut, Escat, Eabsorb, 
     *  MagField,  ElecField, TimeStruc, EdepdEdx, Moliere, AngleB,
     *  Photo, Knckon, ALateCor, Sync,  MuNI, MuBr, MuPr, MagPair

==> Epics.uv8.76.tar.gz: epics/ZepTrackp.h <==
          real*8  Bxu,  Byu,  Bzu  ! uniform mag field comp.
          real*8  Exu,  Eyu,  Ezu  ! uniform elec field comp.
          integer MagField      ! how to give magnetic field
          integer ElecField     ! //          electric field
          real*8  DtMax         ! max allowable path in r.l
          real*8  Tcoef         !
          real*8  Tmin          !
          real*8  Excom1        !  <100GeV;   use XCOM data for compton/p.e effect
          real*8  Excom2        !  < 100GeV;  use XCOM data for pair xsec.
          logical EdepdEdx      ! use energy dependent dE/dx
                                !  F is used to compare analytic calc.
          logical LPMeffect     !  T(default). LPM is effective else off 
          logical TimeStruc     !  
          logical Moliere       ! Moliere's scattering  or  Gaussian
          real*8  EminElec      ! e-'s E < EminElec is discarded
          real*8  EminGamma     ! Egamma < EminGamma is  discarded
          real*8 ElowerBndPair  ! Pair creation is neglected for Eg< this E
          real*8 EupperBndCS    ! Compton scattering is neglected Eg> this E
          integer IncGp         ! Include gp interactions or not
          logical Trace         ! how to take trace info.
          logical FreeC         ! first collision point is fixed or free
          real*8  EpsLeng       ! small distance to adjust boundary 
          real*8 RecoilKEmin    ! Knock-on electron's E> this E is treated
                                ! directly and not included dE/dx.
   	  real*8 Eanihi         ! Ee+ < Eanihi ==> anihilation is considered
          real*8 Ecut           ! cut off energy of brems. (obsolute)
          real*8 Escat          ! Modified scattering const. 
          integer Eabsorb       ! !0 --> photo electric absoption energy is
                                ! counted as energy loss in the media
          logical Photo         ! Photo-electric effect is considered or not
          logical Knckon        ! obsolute
          logical AngleB        ! T==>angle at bremsstrahlung is considered.
          integer ALateCor      ! Angular-Lateral correlated scattering
                                ! is used or not.   0-> no cor. 1 & Moliere=f
                                ! ==> Gaussian cor.  2 ==> even if Moliere=f,
                                !   Gaussian cor. is used.
          integer Sync          ! 0: No Synchrotron considered.
                                ! 1: energy loss by sync. for elec and 'sp'
                                !    if Magfield !=0.
                                ! 2; photon eimission is directly managed
                                !    note Eg is very low.
          integer MuNI          ! 0: no muon n.i, 1: all loss --> dE/dx
                                ! 2: dE/dx(v<vmin) -->  dE/dx. v>vmin is
                                ! by stacastic process. 3: same as 2 but
                                ! n.i is treated explicitly.
          integer MuBr          ! same as MuNI but for bremsstrahlung.
          integer MuPr          ! same as MuNI but for pair creation
          real*8  SyncLoop      ! electron may make a infinite loop in  'sp'.
                                ! If it runs SyncLoop * r, we discard it,
                                ! where r is the cycrtron radius.
          real*8  KEmin         ! minimum kinetic energy of heavy particls
                                ! such as mu, pi, n, p...
                                ! if 0, appropriate value is set by ref. to
                                ! EminElec
          integer MagPair       ! Magnetic pair production is considered or not
                                ! If 0, neglected. if 1 considered. 
                                ! It becomes effective, only if
                                ! Xai=B/Bc*Eg/me/2 > 0.05.
        common /epTrackC/  Bxu,  Byu,  Bzu, Exu, Eyu, Ezu,
     *  DtMax, Tcoef, Tmin, KEmin,
     *  EminElec,  EminGamma, EupperBndCS, IncGp,
     *  Trace,  FreeC, EpsLeng, SyncLoop,
     *  ElowerBndPair, RecoilKEmin,
     *  Eanihi, Ecut, Escat, Eabsorb, Excom1, Excom2,
     *  MagField,  ElecField, TimeStruc, EdepdEdx, Moliere, AngleB,
     *  Photo, Knckon, ALateCor, Sync,  MuNI, MuBr, MuPr, MagPair,
     *  LPMeffect
